@@ -2,6 +2,7 @@
 # Ebbe Library Enpoint
 # =============================================================================
 #
+from ebbe.benchmark import Timer
 from ebbe.iter import (
     as_chunks,
     as_grams,
@@ -13,10 +14,11 @@ from ebbe.iter import (
     with_next,
     with_is_first,
     with_is_last,
-    without_first
+    without_first,
 )
+from ebbe.func import compose, rcompose, count_arity, noop
+from ebbe.format import format_int, format_time, format_seconds, and_join
 from ebbe.utils import (
-    noop,
     get,
     getter,
     getpath,
@@ -26,5 +28,7 @@ from ebbe.utils import (
     grouped,
     partitioned,
     grouped_items,
-    partitioned_items
+    partitioned_items,
+    pick,
+    omit,
 )
